==> tika-2.9.4-src.zip: tika-2.9.4/tika-parsers/tika-parsers-standard/tika-parsers-standard-modules/tika-parser-microsoft-module/src/main/java/org/apache/tika/parser/microsoft/TikaExcelDataFormatter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.parser.microsoft;

import java.util.Locale;

import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

/**
 * Overrides Excel's General format to include more
 * significant digits than the MS Spec allows.
 * See TIKA-2025.
 */
public class TikaExcelDataFormatter extends DataFormatter {

    private String dateOverrideFormatString;

    public TikaExcelDataFormatter() {
        this(LocaleUtil.getUserLocale());
    }

    public TikaExcelDataFormatter(Locale locale) {
        super(locale);
        addFormat("General", new TikaExcelGeneralFormat(locale));
        addFormat("general", new TikaExcelGeneralFormat(locale));
    }

    @Override
    public String formatRawCellContents(double value, int formatIndex, String formatString,
                                        boolean use1904Windowing) {
        if (DateUtil.isADateFormat(formatIndex, formatString)) {
            String activeDateFormatString =
                    (dateOverrideFormatString == null) ? formatString : dateOverrideFormatString;
            return super.formatRawCellContents(value, formatIndex, activeDateFormatString,
                    use1904Windowing);
        } else {
            return super.formatRawCellContents(value, formatIndex, formatString, use1904Windowing);
        }
    }

    public void setDateFormatOverride(String dateOverrideFormat) {
        if (dateOverrideFormat != null && dateOverrideFormat.trim().length() > 0) {
            this.dateOverrideFormatString = dateOverrideFormat;
        }
    }
}

==> tika-3.2.3-src.zip: tika-3.2.3/tika-parsers/tika-parsers-standard/tika-parsers-standard-modules/tika-parser-microsoft-module/src/main/java/org/apache/tika/parser/microsoft/TikaExcelDataFormatter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.parser.microsoft;

import java.util.Locale;

import org.apache.poi.ss.usermodel.DataFormatter;
import org.apache.poi.ss.usermodel.DateUtil;
import org.apache.poi.util.LocaleUtil;

/**
 * Overrides Excel's General format to include more
 * significant digits than the MS Spec allows.
 * See TIKA-2025.
 */
public class TikaExcelDataFormatter extends DataFormatter {

    private String dateOverrideFormatString;

    public TikaExcelDataFormatter() {
        this(LocaleUtil.getUserLocale());
    }

    public TikaExcelDataFormatter(Locale locale) {
        super(locale);
        addFormat("General", new TikaExcelGeneralFormat(locale));
        addFormat("general", new TikaExcelGeneralFormat(locale));
    }

    @Override
    public String formatRawCellContents(double value, int formatIndex, String formatString,
                                        boolean use1904Windowing) {
        if (DateUtil.isADateFormat(formatIndex, formatString)) {
            String activeDateFormatString =
                    (dateOverrideFormatString == null) ? formatString : dateOverrideFormatString;
            return super.formatRawCellContents(value, formatIndex, activeDateFormatString,
                    use1904Windowing);
        } else {
            return super.formatRawCellContents(value, formatIndex, formatString, use1904Windowing);
        }
    }

    public void setDateFormatOverride(String dateOverrideFormat) {
        if (dateOverrideFormat != null && !dateOverrideFormat.isBlank()) {
            this.dateOverrideFormatString = dateOverrideFormat;
        }
    }
}
